@@ -30,7 +30,7 @@ QString RecordUtil::videoLocation(const QString &name)
 void RecordUtil::showNotification(const QString &title, const QString &text, const QString &filePath)
 {
     KNotification *notif = new KNotification("captured");
-    notif->setComponentName(QStringLiteral("plasma_phone_components"));
+    notif->setComponentName(QStringLiteral("plasma_mobile_quicksetting_record"));
     notif->setTitle(title);
     notif->setUrls({QUrl::fromLocalFile(filePath)});
     notif->setText(text);
